==> PythonExtensions-1.5.0-py3-none-any.whl: PythonExtensions/Files/MultiThreadedCopier.py <==
f r o m   s h u t i l   i m p o r t   c o p y 2 
 f r o m   m u l t i p r o c e s s i n g . p o o l   i m p o r t   T h r e a d P o o l 
 i m p o r t   o s 
 f r o m   . F i l e P a t h   i m p o r t   F i l e P a t h 
 f r o m   t y p i n g   i m p o r t   U n i o n 
 
 
 
 
 _ _ a l l _ _   =   [ ' M u l t i T h r e a d e d C o p i e r ' ] 
 
 c l a s s   M u l t i T h r e a d e d C o p i e r ( o b j e c t ) : 
         " " " 
         B a s e d   o n   h t t p s : / / s t a c k o v e r f l o w . c o m / a / 6 4 8 1 3 4 2 2 
 
 s r c _ d i r   =   / p a t h / t o / s r c / d i r 
 d e s t _ d i r   =   / p a t h / t o / d e s t / d i r 
 
 w i t h   M u l t i T h r e a d e d C o p i e r ( m a x _ t h r e a d s = 1 6 )   a s   c o p i e r : 
         s h u t i l . c o p y t r e e ( s r c _ d i r ,   d e s t _ d i r ,   c o p y _ f u n c t i o n = c o p i e r . c o p y ) 
         " " " 
         d e f   _ _ i n i t _ _ ( s e l f ,   m a x _ t h r e a d s :   i n t   =   o s . c p u _ c o u n t ( ) ) :   s e l f . _ m a x _ t h r e a d s   =   m a x _ t h r e a d s 
         d e f   _ _ e n t e r _ _ ( s e l f ) : 
                 s e l f . p o o l   =   T h r e a d P o o l ( s e l f . _ m a x _ t h r e a d s ) 
                 r e t u r n   s e l f 
         d e f   _ _ e x i t _ _ ( s e l f ,   e x c _ t y p e ,   e x c _ v a l ,   e x c _ t b ) : 
                 s e l f . p o o l . c l o s e ( ) 
                 s e l f . p o o l . j o i n ( ) 
                 d e l   s e l f . p o o l 
 
         d e f   c o p y ( s e l f ,   s o u r c e :   U n i o n [ s t r ,   F i l e P a t h ] ,   d e s t :   U n i o n [ s t r ,   F i l e P a t h ] ) :   r e t u r n   s e l f . p o o l . a p p l y _ a s y n c ( c o p y 2 ,   a r g s = ( s o u r c e ,   d e s t ) ) 
 

==> PythonExtensions-2.0.0-py3-none-any.whl: PythonExtensions/Files/MultiThreadedCopier.py <==
i m p o r t   o s 
 f r o m   m u l t i p r o c e s s i n g . p o o l   i m p o r t   T h r e a d P o o l 
 f r o m   s h u t i l   i m p o r t   c o p y 2 
 f r o m   t y p i n g   i m p o r t   U n i o n 
 
 f r o m   . F i l e P a t h   i m p o r t   F i l e P a t h 
 
 
 
 
 _ _ a l l _ _   =   [ ' M u l t i T h r e a d e d C o p i e r ' ] 
 
 c l a s s   M u l t i T h r e a d e d C o p i e r ( o b j e c t ) : 
         " " " 
         B a s e d   o n   h t t p s : / / s t a c k o v e r f l o w . c o m / a / 6 4 8 1 3 4 2 2 
 
 s r c _ d i r   =   / p a t h / t o / s r c / d i r 
 d e s t _ d i r   =   / p a t h / t o / d e s t / d i r 
 
 w i t h   M u l t i T h r e a d e d C o p i e r ( m a x _ t h r e a d s = 1 6 )   a s   c o p i e r : 
         s h u t i l . c o p y t r e e ( s r c _ d i r ,   d e s t _ d i r ,   c o p y _ f u n c t i o n = c o p i e r . c o p y ) 
         " " " 
         _ _ s l o t s _ _   =   [ ' p o o l ' ,   ' _ m a x _ t h r e a d s ' ] 
         d e f   _ _ i n i t _ _ ( s e l f ,   m a x _ t h r e a d s :   i n t   =   o s . c p u _ c o u n t ( ) ) :   s e l f . _ m a x _ t h r e a d s   =   m a x _ t h r e a d s 
         d e f   _ _ e n t e r _ _ ( s e l f ) : 
                 s e l f . p o o l   =   T h r e a d P o o l ( s e l f . _ m a x _ t h r e a d s ) 
                 r e t u r n   s e l f 
         d e f   _ _ e x i t _ _ ( s e l f ,   e x c _ t y p e ,   e x c _ v a l ,   e x c _ t b ) : 
                 s e l f . p o o l . c l o s e ( ) 
                 s e l f . p o o l . j o i n ( ) 
                 d e l   s e l f . p o o l 
 
         d e f   c o p y ( s e l f ,   s o u r c e :   U n i o n [ s t r ,   F i l e P a t h ] ,   d e s t :   U n i o n [ s t r ,   F i l e P a t h ] ) :   r e t u r n   s e l f . p o o l . a p p l y _ a s y n c ( c o p y 2 ,   a r g s = ( s o u r c e ,   d e s t ) ) 
 
